#!/bin/bash

if [[ ! -n  "${JUGGLER_DETECTOR}" ]] ; then
  export JUGGLER_DETECTOR="topside"
fi

if [[ ! -n  "${JUGGLER_N_EVENTS}" ]] ; then
  export JUGGLER_N_EVENTS=100
fi

export JUGGLER_FILE_NAME_TAG="rich_forward_hadrons"
export JUGGLER_GEN_FILE="${JUGGLER_FILE_NAME_TAG}.hepmc"

export JUGGLER_SIM_FILE="sim_${JUGGLER_FILE_NAME_TAG}.root"
export JUGGLER_REC_FILE="rec_${JUGGLER_FILE_NAME_TAG}.root"

echo "JUGGLER_N_EVENTS = ${JUGGLER_N_EVENTS}"
echo "JUGGLER_DETECTOR = ${JUGGLER_DETECTOR}"


# Build the detector constructors.
git clone https://eicweb.phy.anl.gov/EIC/detectors/${JUGGLER_DETECTOR}.git
mkdir ${JUGGLER_DETECTOR}/build
pushd ${JUGGLER_DETECTOR}/build
cmake ../. -DCMAKE_INSTALL_PREFIX=/usr/local && make -j30 install
popd

# generate the input events
# note datasets is now only used to develop datasets.
#git clone https://eicweb.phy.anl.gov/EIC/datasets.git datasets
python rich/scripts/rich_data_gen.py \
       ${JUGGLER_FILE_NAME_TAG}.hepmc \
       -n ${JUGGLER_N_EVENTS} \
       --pmin 5.0 \
       --pmax 100.0 \
       --angmin 3.0 \
       --angmax 8.0

pushd ${JUGGLER_DETECTOR}
ls -l
# run geant4 simulations
python options/ForwardRICH/simu.py \
       --compact=${JUGGLER_DETECTOR}.xml \
       -i ../${JUGGLER_FILE_NAME_TAG}.hepmc \
       -o ${JUGGLER_SIM_FILE}
       -n ${JUGGLER_N_EVENTS}

# @TODO changeable simulation file name and detector xml file name
xenv -x /usr/local/Juggler.xenv gaudirun.py ../rich/options/rich_reco.py
ls -l
popd

# @TODO add analysis scripts
#root_filesize=$(stat --format=%s "${JUGGLER_DETECTOR}/${JUGGLER_REC_FILE}")
#if [[ "${JUGGLER_N_EVENTS}" -lt "500" ]] ; then 
#  # file must be less than 10 MB to upload
#  if [[ "${root_filesize}" -lt "10000000" ]] ; then 
#    cp ${JUGGLER_DETECTOR}/${JUGGLER_REC_FILE} results/.
#  fi
#fi

